@@ -9,21 +9,21 @@
 // or else upgrading old project file will not work
 // reliably.
 // TODO QGIS 4: remove in favor of _QGIS_VERSION
-#define VERSION "3.24.3-Tisler"
-#define _QGIS_VERSION "3.24.3-Tisler"
+#define VERSION "3.26.2-Buenos Aires"
+#define _QGIS_VERSION "3.26.2-Buenos Aires"
 
 //used in vim src/core/qgis.cpp
 //The way below should work but it resolves to a number like 0110 which the compiler treats as octal I think
 //because debuggin it out shows the decimal number 72 which results in incorrect version status.
 //As a short term fix I (Tim) am defining the version in top level cmake. It would be good to
 //reinstate this more generic approach below at some point though
-//#define VERSION_INT 3243
+//#define VERSION_INT 3262
 // TODO QGIS 4: Remove in favor of _QGIS_VERSION_INT
-#define VERSION_INT 32403
-#define _QGIS_VERSION_INT 32403
-#define ABISYM(x) x ## 32403
+#define VERSION_INT 32602
+#define _QGIS_VERSION_INT 32602
+#define ABISYM(x) x ## 32602
 //used in main.cpp and anywhere else where the release name is needed
-#define RELEASE_NAME "Tisler"
+#define RELEASE_NAME "Buenos Aires"
 
 #define QGIS_PLUGIN_SUBDIR "lib/qgis/plugins"
 #define QGIS_DATA_SUBDIR "share/qgis"
@@ -31,7 +31,7 @@
 #define QGIS_LIB_SUBDIR "lib"
 #define QGIS_QML_SUBDIR "qml"
 #define CMAKE_INSTALL_PREFIX "/usr"
-#define CMAKE_SOURCE_DIR "/build/qgis/src/qgis-3.24.3"
+#define CMAKE_SOURCE_DIR "/build/qgis/src/qgis-3.26.2"
 
 #define QGIS_SERVER_MODULE_SUBDIR "lib/qgis/server"
 
@@ -46,14 +46,14 @@
 
 #define QT_PLUGINS_DIR "/usr/lib/qt/plugins"
 
-#define PYTHON_VERSION "3.10.4"
+#define PYTHON_VERSION "3.10.6"
 #define PYTHON_VERSION_MAJOR "3"
 #define PYTHON_VERSION_MINOR "10"
-#define PYTHON_VERSION_PATCH "4"
+#define PYTHON_VERSION_PATCH "6"
 
-#define PROJ_VERSION_MAJOR 8
-#define PROJ_VERSION_MINOR 2
-#define PROJ_VERSION_PATCH 0
+#define PROJ_VERSION_MAJOR 9
+#define PROJ_VERSION_MINOR 0
+#define PROJ_VERSION_PATCH 1
 
 /* #undef USING_NMAKE */
 
@@ -98,13 +98,15 @@
 
 #define HAVE_EPT
 
+#define HAVE_COPC
+
 #define HAVE_PDAL_QGIS
-#define PDAL_VERSION "2.4.1"
+#define PDAL_VERSION "2.4.3"
 #define PDAL_VERSION_MAJOR_INT 2
 #define PDAL_VERSION_MINOR_INT 4
 #define PDAL_VERSION_MAJOR "2"
 #define PDAL_VERSION_MINOR "4"
-#define PDAL_VERSION_MICRO "1"
+#define PDAL_VERSION_MICRO "3"
 
 #define ENABLE_TESTS
 
